@@ -1,19 +1,26 @@
-import json
+"""
+    instagramy.InstagramUser
+    ~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-import requests
-from bs4 import BeautifulSoup
-from fake_useragent import UserAgent
+    This module scrape data
+    of given Instagram User.
 
-headers = {"UserAgent": UserAgent().random}
+    Usage Example
+    -------------
+    ::
 
+        from instagramy.InstagramUser import InstagramUser
 
-def extract_user_profile(script) -> dict:
-    """
-    May raise json.decoder.JSONDecodeError
-    """
-    data = script.contents[0]
-    info = json.loads(data[data.find('{"config"') : -1])
-    return info["entry_data"]["ProfilePage"][0]["graphql"]["user"]
+        >>> user = InstagramUser('github')
+        >>> user.is_verified
+        >>> user.number_of_followers
+        >>> user.biography
+
+"""
+
+from .core.parser import ParseUser
+from .core.requests import get
+from .core.exceptions import UsernameNotFound, HTTPError
 
 
 class InstagramUser:
@@ -27,6 +34,7 @@ class InstagramUser:
     """
 
     def __init__(self, username: str):
+
         self.url = f"https://www.instagram.com/{username}/"
         self.user_data = self.get_json()
 
@@ -34,62 +42,74 @@ class InstagramUser:
         """
         Return a dict of user information
         """
-        html = requests.get(self.url, headers=headers).text
-        scripts = BeautifulSoup(html, "html.parser").find_all("script")
         try:
-            return extract_user_profile(scripts[4])
-        except (json.decoder.JSONDecodeError, KeyError):
-            return extract_user_profile(scripts[3])
+            html = get(self.url)
+        except HTTPError:
+            raise UsernameNotFound(self.url.split("/")[-2])
+            
+        parser = ParseUser()
+        parser.feed(html)
+        return parser.Data
 
     @property
     def username(self) -> str:
+        """ Username of the given user """
         return self.user_data["username"]
 
     @property
     def fullname(self) -> str:
+        """ Fullname of the given user """
         return self.user_data["full_name"]
 
     @property
     def biography(self) -> str:
+        """ Biography of the given user """
         return self.user_data["biography"]
 
     @property
     def email(self) -> str:
+        """ Email of the given user """
         return self.user_data["business_email"]
 
     @property
     def website(self) -> str:
+        """ Website of the given user """
         return self.user_data["external_url"]
 
     @property
     def number_of_followers(self) -> int:
+        """ No.of Followers of the given user """
         return self.user_data["edge_followed_by"]["count"]
 
     @property
     def number_of_followings(self) -> int:
+        """ No.of Following of the given user """
         return self.user_data["edge_follow"]["count"]
 
     @property
     def number_of_posts(self) -> int:
+        """ No.of Post of the given user """
         return self.user_data["edge_owner_to_timeline_media"]["count"]
 
     @property
     def profile_picture_url(self) -> str:
+        """ Profile picture url of the Given User """
         return self.user_data["profile_pic_url_hd"]
 
     @property
     def is_verified(self) -> bool:
+        """ Verification status of the user """
         return self.user_data["is_verified"]
 
     @property
     def is_private(self) -> bool:
+        """ Account type is Private """
         return self.user_data["is_private"]
 
     @property
     def posts(self) -> list:
         """
-        Only returns recent 12 post details
-        User account must be non private account
+        Top 12 posts data of the given user
         """
 
         posts_lists = []
@@ -128,7 +148,7 @@ class InstagramUser:
                 data[
                     "post_url"
                 ] = f'https://www.instagram.com/p/{i["node"]["shortcode"]}/'
-            except:
+            except (KeyError, TypeError):
                 data["post_url"] = None
             try:
                 data["display_url"] = i["node"]["display_url"]
@@ -140,14 +160,16 @@ class InstagramUser:
     @property
     def posts_display_urls(self) -> list:
         """
-        Only return recents 12 posts url
-        User account must be non private account
+        Top 12 posts picture url of the given user
         """
 
         return [i["display_url"] for i in self.posts]
 
     @property
     def other_info(self) -> dict:
+        """
+        Other information about user
+        """
         return {
             "is_private": self.user_data["is_private"],
             "is_verified": self.user_data["is_verified"],
